@@ -27,7 +27,7 @@ class Act(models.Model):
             print err
             return False
         act_skel = os.path.join(bs_home, 'skel/act')
-        act_path = os.path.join(self.PROJECT_ROOT, 'acts/%s' % act_name)
+        act_path = os.path.join(self.VENUE_ROOT, 'acts/%s' % act_name)
         try:
             shutil.copytree(act_skel, act_path)
         except:
@@ -45,7 +45,7 @@ class Site(models.Model):
     active = models.BooleanField(default=True)
 
     class Meta():
-        db_table = 'backstage_project'
+        db_table = 'backstage_venue'
 
 
 class Stage(models.Model):
